@@ -3,7 +3,7 @@ from typing import Any, List, Tuple, Union
 from eth_abi.abi import encode
 from eth_utils.abi import function_abi_to_4byte_selector
 
-from .exceptions import InputDataError
+from .exceptions import UNABLE_TO_DETECT_CONSTRUCTOR_ARGUMENTS
 
 __all__ = (
     "get_constructor_type",
@@ -71,15 +71,12 @@ def detect_constructor_arguments(
     types, _ = get_types_names(type_def["inputs"])
     default_values: List[Any] = []
     for t in types:
-        if "int" in t:
+        if t.endswith("[]"):
+            raise UNABLE_TO_DETECT_CONSTRUCTOR_ARGUMENTS
+        elif "int" in t:
             default_values.append(0)
-        elif "[]" in t:
-            raise InputDataError(
-                "Unable to detect arguments including array. "
-                "Please provide the bytecode."
-            )
         elif "string" == t:
-            default_values.append("")
+            default_values.append("0")
         elif "bool" == t:
             default_values.append(False)
         elif "address" == t:
